@@ -1,8 +1,8 @@
 __title__ = 'jsonselect'
-__version__ = '0.1b'
+__version__ = '0.2'
 __author__ = 'Matthew Hooker'
 __license__ = 'ISC'
 __copyright__ = 'Copyright 2011 Matthew Hooker'
 
 
-from jsonselect import select
+from .jsonselect import select
